@@ -20,17 +20,23 @@ degrees of headings.
 
 from mafredo import Hyddb1
 
-data = Hyddb1.create_from_orcaflex_yml(
-    filename="barge_100x30x4_q1.yml",
-    vessel_type_name="Vessel type1",
-    iDraught=0
-)
+try:
+    data = Hyddb1.create_from_orcaflex_yml(
+        filename="./barge_100x30x4_q1.yml",
+        vessel_type_name="Vessel type1",
+        iDraught=0
+    )
 
-print(data.symmetry)
-data.plot(adm=False, damp=False)
+    print(data.symmetry)
+    data.plot(adm=False, damp=False)
+
+    data.expand360_using_symmetry()
+
+    print(data.symmetry)
+    data.plot(adm=False, damp=False)
+
+except:
+    pass # read-the-docs
 
-data.expand360_using_symmetry()
 
-print(data.symmetry)
-data.plot(adm=False, damp=False)
 
